@@ -1,5 +1,5 @@
 package IO::All::STDIO;
-$IO::All::STDIO::VERSION = '0.62';
+$IO::All::STDIO::VERSION = '0.63';
 use strict;
 use warnings;
 use IO::All -base;
@@ -52,33 +52,4 @@ sub open_stderr {
 
 # XXX Add overload support
 
-=encoding utf8
-
-=head1 NAME
-
-IO::All::STDIO - STDIO Support for IO::All
-
-=head1 SYNOPSIS
-
-See L<IO::All>.
-
-=head1 DESCRIPTION
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2004-2005. Brian Ingerson.
-
-Copyright (c) 2006-2014. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
-
 1;
